function YSH=XYZ2YSH(XYZ,XYZn)

%
% YSH = XYZ2YSH(XYZ, XYZn)
%
% Function for calculating CIE 1931 tristimulus values in XYZ from the Fairchild appearance scale in lightness Y,
% saturation S, and hue h.
%
% Inputs:   CIE 1931 tristimulus values in XYZ
%           XYZw, whitepoint for computing saturation
%
%
% Output: Color appearance attributes of
%           L, Lightness
%          S, Saturation
%          H, hue angle
%
%
% Written by Rodney L. Heckaman
% rlh9572@cis.rit.edu
%
% Last Modified 02/20/2012

global up vp

Const=makecform('xyz2upvpl');

upvpl=applycform(XYZ,Const);
u=upvpl(:,1);v=upvpl(:,2);

upvpln=applycform(XYZn,Const);
un=upvpln(:,1);vn=upvpln(:,2);

IPT=XYZ2IPT(XYZ);

xi=(180/pi)*atan2(IPT(:,3),IPT(:,2));
IX=find(xi<0);
xi(IX)=360+xi(IX);

load Locus %The locus of pure color in CIE u'v' Chromaticities

x=Hue;

Y=uprime;
u_Locus=interp1(x,Y,xi,'spline');

Y=vprime;
v_Locus=interp1(x,Y,xi,'spline');

H=xi;

clear Y x xi
    
S=sqrt((u-un).^2+(v-vn).^2)./sqrt((u_Locus-un).^2+(v_Locus-vn).^2);

for m=1:size(XYZ,1)
    
	up=u(m);vp=v(m);
	x=fminbnd(@Lightness,0,100);;
    Y(m)=upvpl(m,3)/x;

end

Y=Y';

YSH=[Y S H];
            
