function XYZ=YSH2XYZ(YSH,XYZn)

%
% XYZ = YSH2XYZ(YSH, XYZn)
%
% Function for calculating CIE 1931 tristimulus values in XYZ from the Fairchild appearance scale in lightness Y,
% saturation S, and hue h.
%
% Inputs:   YSH, the appearance scale values in lightness Y, saturation S, and hue h
%           XYZw, whitepoint
%
% Output: CIE 1931 tristimulus values in XYZ
%
% Written by Rodney L. Heckaman
% rlh9572@cis.rit.edu
%
% Last Modified 02/20/2012

global up vp L C un vn H uvprime

%Chromatities of the White Point
Const=makecform('xyz2upvpl');
upvpln=applycform(XYZn,Const);
un=upvpln(:,1);vn=upvpln(:,2);
clear upvpln

%Chromticites of the spectrum locus at the input hue
load locus %The locus of pure color in CIE u'v' Chromaticities


x=Hue;
xi=YSH(:,3);
Y=uprime;
u_Locus=interp1(x,Y,xi,'spline');
Y=vprime;
v_Locus=interp1(x,Y,xi,'spline');

Const=makecform('upvpl2xyz');

for m=1:size(YSH,1)
        
    Y=YSH(m,1);
    S=YSH(m,2);
    H=YSH(m,3);
    
    C=sqrt(((u_Locus(m)-un)^2+(v_Locus(m)-vn)^2)*S^2);%Length of u'v' vector to maintain saturation
        
    %Estimate upvpl for starting values
    
    up=un+S*(u_Locus(m)-un);
    vp=vn+S*(v_Locus(m)-vn);
    
    x=fminbnd(@Lightness,0,100);%Find the lightness at GO at the estimated chromaticities
    L=x*Y;
        
    x0=[up vp];
    [x,fval]=fminsearch(@upvp,x0);%Perform a search at the input hue for the chromaticities u'v' for the input while maintaining saturation.
    
    up=uvprime(1);vp=uvprime(2);
        
    %Then the final lightness value computed relative to the value of G0 the chromaticities u'v'
    L_Max=fminbnd(@Lightness,0,100);
    
    XYZ(m,:)=applycform([up vp L_Max*Y],Const); %And finally, the tristimulus values
    
end

return







