function output=convert_NCS(XYZ); 

%
% output=convert_NCS(XYZ)
%
% Function for calculating NCS blackness s, chromaticednes c, and hue from
% the CIE 1931 tristimulus values in XYZ 
% saturation S, and hue h.
%
% Inputs:   CIE 1931 tristimulus values in XYZ
%
%
% Output: Color appearance attributes of the Natural Color System NCS
%           s, NCS blackness
%           c, NCS chromaticedness
%           h, NCS hue
%
% Written by Rodney L. Heckaman
% rlh9572@cis.rit.edu
%
% Last Modified 02/20/2012

WP_D65=100*[0.9505 1.0000 1.0890];
load 'NCS_D65'

C_lab=makecform('xyz2lab','WhitePoint',WP_D65);
C_LCh=makecform('lab2lch');

%Compute Hue

Lab=applycform(XYZ,C_lab);
LCh=applycform(Lab,C_LCh);

h_ab=LCh(:,3);

P=[];

for n=1:size(h_ab_bar,1)
    P=[P normpdf(h_ab,h_ab_bar(n),h_ab_SD(n))];
end

[max_P,Index]=max(P');
Index=Index';

Z=[...
        LCh(:,1).^3 LCh(:,1).^2 LCh(:,1) ...
        LCh(:,2).^2 LCh(:,2) ...
        ones(size(h_ab,1),1)...
        ];


%Find most likely hue triangle in NCS
    
for n=1:size(h_ab,1)
    
    I=Index(n);
    
    status=0;
    
    while status==0
    
        for k=1:3
        
            j=I+k-2;
            
            if j==0
                j=size(h_ab_bar,1);
            end
            if j>size(h_ab_bar,1);
                j=1;
            end
    
            beta=squeeze(Beta(j,:,:));
            T(k,:)=Z(n,:)*beta;
        
        end
    
        if T(1,3)>T(2,3);
            T(1,3)=T(1,3)-360;
        end
    
        if T(2,3)>T(3,3);
            T(3,3)=T(3,3)+360;
        end
        
        if T(1,3)>h_ab(n)
            I=I-1;
            if I<1
                I=size(h_ab_bar,1)
            end
        end
        
        if T(3,3)<h_ab(n)
            I=I+1;
            if I>size(h_ab_bar,1)
                I=1
            end
        end            
        
        if T(1,3)<h_ab(n)&T(3,3)>h_ab(n)
            status=1;
        end            
    end

    x=T(:,3);
    S=T(:,1);
    C=T(:,2);
    
    output(n,:) = [interp1(x,S,h_ab(n)) interp1(x,C,h_ab(n))];
                    
end

% output(find(output(:,1)<0),1)=0;
% output(find(output(:,2)<0),2)=0;
% 
% output(find(output(:,1)>100),1)=100;
% output(find(output(:,2)>100),2)=100;


