
% Application for calculating the Fairchild appearance scale in lightness
% Y, saturation S, and hue h from the tristimulus values for the 24 NCS Aim
% Hues
%
% Written by Rodney L. Heckaman
% rlh9572@cis.rit.edu
%
% Last Modified 02/20/2012

clear
clc
close all

global up vp

addpath('/Users/rod2/Documents/MATLAB/Matlab_Workspace/CIECAM02/ciecam02_ti')
addpath('/Users/rod2/Documents/MATLAB/Matlab_Workspace/NCSNotation')

Hue_0=[...
    '   Y';'YIOR';'Y30R';'Y50R';'Y70R';'Y90R';'   R';'RIOB';'R30B';'R50B';'R70B';'R90B';'   B';'B10G';...
    'B30G';'B50G';'B70G';'B90G';'   G';'G10Y';'G30Y';'G50Y';'G70Y';'G90Y'];

WP_1931=[98.07 100.00 118.23]; %1931 Obsever, Illum. C
WP_D65=100*[0.9505 1.0000 1.0890]; %D50 2 Degree

Data=csvread('NCS_Notation.csv'); %Tristimunlus values for the 24 NCS aim hues in the CIE Illuminant C

Const1=makecform('xyz2upvpl');
Const2=makecform('xyz2srgb');

q=0;

for n=[8 7 6 5 4 3 2 1 24 23 22 21 20 19 18 17 16 15 14 13 12 11 10 9]
    
    Hue_0(n,:)
        
    N=3+7*(n-1);
    XYZ=Data(:,N+1:N+3);
    
    Index=find(XYZ(:,1)~=0&XYZ(:,2)~=0&XYZ(:,3)~=0);
    XYZ(Index,:) = camcat_cc(XYZ(Index,:)',WP_1931',WP_D65',1,'cie')'; %Convert to D65
    XYZ = camcat_cc(XYZ(Index,:)',WP_1931',WP_D65',1,'cie')'; %Convert to D65
    
    YSH=XYZ2YSH(XYZ,WP_D65)
    
end
